@@ -86,8 +86,27 @@ class RethinkDBClient(BaseStorageClient):
             object_space
         ).table(
             object_type
-        ).filter(
-            {'object_id': object_id}
+        ).get_all(
+            object_id,
+            index='object_id'
+        ).limit(1).run(self._connection)
+
+        items = [item async for item in result]
+        if len(items) < 1:
+            return None
+
+        return obj_cls(**items[0])
+
+    async def get_from_index(self, obj_cls, object_space, object_type, value, index):
+        await self.init_table(object_space, object_type, obj_cls._indexes)
+
+        result = await r.db(
+            object_space
+        ).table(
+            object_type
+        ).get_all(
+            value,
+            index=index
         ).limit(1).run(self._connection)
 
         items = [item async for item in result]
